@@ -1,6 +1,6 @@
 /*
 
-	twepcrack - Wep Key Cracker
+	weplab - Wep Key Cracker
 
 	Copyright (C) 2004 Jose Ignacio Sanchez Martin - Topo[LB]
 
@@ -35,6 +35,7 @@ typedef struct{
 	unsigned char key[13];
 	t_keyspace keyspace[13];
 	short logicalStatus[13];
+	int byte0IntValue;
 } t_bruteforceKey;
 
 void bruteforce (void);
