@@ -26,6 +26,11 @@
 #ifndef	_CAPTURE_H
 #define	_CAPTURE_H
 
+#ifndef DLT_PRISM_HEADER
+#define DLT_PRISM_HEADER 119 /* prism header, not defined on some platforms */
+#endif
+
+
 void captureWeakPackets(void);
 void captureWepDataPackets(void);
 
