@@ -1,6 +1,6 @@
 /*
 
-	twepcrack - Wep Key Cracker
+	weplab - Wep Key Cracker
 
 	Copyright (C) 2004 Jose Ignacio Sanchez Martin - Topo[LB]
 
@@ -27,6 +27,6 @@
 #include "globals.h"
 
 
-t_global_v global_v={0,0,0,"","","","",5,0,0,0,0,0,"",100,0,50,1,2,"",0,2};
+t_global_v global_v={0,0,0,"","wlan0","","",5,0,0,0,0,0,"",100,0,50,1,2,"",0,2,0,0,""};
 unsigned char S_InitialBackup[256];
 
